Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterAgentRuntimeServer(s grpc.ServiceRegistrar, srv AgentRuntimeServer)
- type AgentRuntimeClient
- type AgentRuntimeServer
- type AgentRuntime_ChatStreamClient
- type AgentRuntime_ChatStreamServer
- type ChatRequest
- func (*ChatRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ChatRequest) GetPrompt() string
- func (x *ChatRequest) GetSessionId() string
- func (*ChatRequest) ProtoMessage()
- func (x *ChatRequest) ProtoReflect() protoreflect.Message
- func (x *ChatRequest) Reset()
- func (x *ChatRequest) String() string
- type ChatResponse
- type ChatStreamEvent
- func (*ChatStreamEvent) Descriptor() ([]byte, []int)deprecated
- func (x *ChatStreamEvent) GetContent() string
- func (x *ChatStreamEvent) GetStep() int32
- func (x *ChatStreamEvent) GetTool() string
- func (x *ChatStreamEvent) GetType() string
- func (*ChatStreamEvent) ProtoMessage()
- func (x *ChatStreamEvent) ProtoReflect() protoreflect.Message
- func (x *ChatStreamEvent) Reset()
- func (x *ChatStreamEvent) String() string
- type ChatStreamRequest
- func (*ChatStreamRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ChatStreamRequest) GetPrompt() string
- func (x *ChatStreamRequest) GetRegenerate() bool
- func (x *ChatStreamRequest) GetSessionId() string
- func (*ChatStreamRequest) ProtoMessage()
- func (x *ChatStreamRequest) ProtoReflect() protoreflect.Message
- func (x *ChatStreamRequest) Reset()
- func (x *ChatStreamRequest) String() string
- type DeleteSessionRequest
- func (*DeleteSessionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteSessionRequest) GetSessionId() string
- func (*DeleteSessionRequest) ProtoMessage()
- func (x *DeleteSessionRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteSessionRequest) Reset()
- func (x *DeleteSessionRequest) String() string
- type DeleteSessionResponse
- type HealthRequest
- type HealthResponse
- func (*HealthResponse) Descriptor() ([]byte, []int)deprecated
- func (x *HealthResponse) GetAgentName() string
- func (x *HealthResponse) GetModel() string
- func (x *HealthResponse) GetStatus() string
- func (*HealthResponse) ProtoMessage()
- func (x *HealthResponse) ProtoReflect() protoreflect.Message
- func (x *HealthResponse) Reset()
- func (x *HealthResponse) String() string
- type ListSessionMessagesRequest
- func (*ListSessionMessagesRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ListSessionMessagesRequest) GetLimit() int32
- func (x *ListSessionMessagesRequest) GetSessionId() string
- func (*ListSessionMessagesRequest) ProtoMessage()
- func (x *ListSessionMessagesRequest) ProtoReflect() protoreflect.Message
- func (x *ListSessionMessagesRequest) Reset()
- func (x *ListSessionMessagesRequest) String() string
- type ListSessionMessagesResponse
- func (*ListSessionMessagesResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListSessionMessagesResponse) GetMessages() []*SessionMessage
- func (*ListSessionMessagesResponse) ProtoMessage()
- func (x *ListSessionMessagesResponse) ProtoReflect() protoreflect.Message
- func (x *ListSessionMessagesResponse) Reset()
- func (x *ListSessionMessagesResponse) String() string
- type ListSessionsRequest
- type ListSessionsResponse
- func (*ListSessionsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListSessionsResponse) GetSessions() []*SessionInfo
- func (*ListSessionsResponse) ProtoMessage()
- func (x *ListSessionsResponse) ProtoReflect() protoreflect.Message
- func (x *ListSessionsResponse) Reset()
- func (x *ListSessionsResponse) String() string
- type PromptObjectRequest
- func (*PromptObjectRequest) Descriptor() ([]byte, []int)deprecated
- func (x *PromptObjectRequest) GetPrompt() string
- func (x *PromptObjectRequest) GetSchemaDesc() string
- func (x *PromptObjectRequest) GetSchemaJson() []byte
- func (x *PromptObjectRequest) GetSchemaName() string
- func (*PromptObjectRequest) ProtoMessage()
- func (x *PromptObjectRequest) ProtoReflect() protoreflect.Message
- func (x *PromptObjectRequest) Reset()
- func (x *PromptObjectRequest) String() string
- type PromptObjectResponse
- func (*PromptObjectResponse) Descriptor() ([]byte, []int)deprecated
- func (x *PromptObjectResponse) GetObjectJson() []byte
- func (x *PromptObjectResponse) GetRawText() string
- func (*PromptObjectResponse) ProtoMessage()
- func (x *PromptObjectResponse) ProtoReflect() protoreflect.Message
- func (x *PromptObjectResponse) Reset()
- func (x *PromptObjectResponse) String() string
- type ReadyRequest
- type ReadyResponse
- type SessionInfo
- func (*SessionInfo) Descriptor() ([]byte, []int)deprecated
- func (x *SessionInfo) GetId() string
- func (x *SessionInfo) GetLastActive() int64
- func (x *SessionInfo) GetMessageCount() int32
- func (*SessionInfo) ProtoMessage()
- func (x *SessionInfo) ProtoReflect() protoreflect.Message
- func (x *SessionInfo) Reset()
- func (x *SessionInfo) String() string
- type SessionMessage
- func (*SessionMessage) Descriptor() ([]byte, []int)deprecated
- func (x *SessionMessage) GetActiveBranch() int32
- func (x *SessionMessage) GetBranchesJson() string
- func (x *SessionMessage) GetContent() string
- func (x *SessionMessage) GetCreatedAt() int64
- func (x *SessionMessage) GetRole() string
- func (*SessionMessage) ProtoMessage()
- func (x *SessionMessage) ProtoReflect() protoreflect.Message
- func (x *SessionMessage) Reset()
- func (x *SessionMessage) String() string
- type UnimplementedAgentRuntimeServer
- func (UnimplementedAgentRuntimeServer) Chat(context.Context, *ChatRequest) (*ChatResponse, error)
- func (UnimplementedAgentRuntimeServer) ChatStream(*ChatStreamRequest, grpc.ServerStreamingServer[ChatStreamEvent]) error
- func (UnimplementedAgentRuntimeServer) DeleteSession(context.Context, *DeleteSessionRequest) (*DeleteSessionResponse, error)
- func (UnimplementedAgentRuntimeServer) Health(context.Context, *HealthRequest) (*HealthResponse, error)
- func (UnimplementedAgentRuntimeServer) ListSessionMessages(context.Context, *ListSessionMessagesRequest) (*ListSessionMessagesResponse, error)
- func (UnimplementedAgentRuntimeServer) ListSessions(context.Context, *ListSessionsRequest) (*ListSessionsResponse, error)
- func (UnimplementedAgentRuntimeServer) PromptObject(context.Context, *PromptObjectRequest) (*PromptObjectResponse, error)
- func (UnimplementedAgentRuntimeServer) Ready(context.Context, *ReadyRequest) (*ReadyResponse, error)
- type UnsafeAgentRuntimeServer
Constants ¶
const ( AgentRuntime_Chat_FullMethodName = "/openotters.agent.v1.AgentRuntime/Chat" AgentRuntime_ChatStream_FullMethodName = "/openotters.agent.v1.AgentRuntime/ChatStream" AgentRuntime_PromptObject_FullMethodName = "/openotters.agent.v1.AgentRuntime/PromptObject" AgentRuntime_ListSessions_FullMethodName = "/openotters.agent.v1.AgentRuntime/ListSessions" AgentRuntime_DeleteSession_FullMethodName = "/openotters.agent.v1.AgentRuntime/DeleteSession" AgentRuntime_ListSessionMessages_FullMethodName = "/openotters.agent.v1.AgentRuntime/ListSessionMessages" AgentRuntime_Health_FullMethodName = "/openotters.agent.v1.AgentRuntime/Health" AgentRuntime_Ready_FullMethodName = "/openotters.agent.v1.AgentRuntime/Ready" )
Variables ¶
var AgentRuntime_ServiceDesc = grpc.ServiceDesc{ ServiceName: "openotters.agent.v1.AgentRuntime", HandlerType: (*AgentRuntimeServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Chat", Handler: _AgentRuntime_Chat_Handler, }, { MethodName: "PromptObject", Handler: _AgentRuntime_PromptObject_Handler, }, { MethodName: "ListSessions", Handler: _AgentRuntime_ListSessions_Handler, }, { MethodName: "DeleteSession", Handler: _AgentRuntime_DeleteSession_Handler, }, { MethodName: "ListSessionMessages", Handler: _AgentRuntime_ListSessionMessages_Handler, }, { MethodName: "Health", Handler: _AgentRuntime_Health_Handler, }, { MethodName: "Ready", Handler: _AgentRuntime_Ready_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "ChatStream", Handler: _AgentRuntime_ChatStream_Handler, ServerStreams: true, }, }, Metadata: "executor/api/v1/agent.proto", }
AgentRuntime_ServiceDesc is the grpc.ServiceDesc for AgentRuntime service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_executor_api_v1_agent_proto protoreflect.FileDescriptor
Functions ¶
func RegisterAgentRuntimeServer ¶
func RegisterAgentRuntimeServer(s grpc.ServiceRegistrar, srv AgentRuntimeServer)
Types ¶
type AgentRuntimeClient ¶
type AgentRuntimeClient interface {
// Chat
Chat(ctx context.Context, in *ChatRequest, opts ...grpc.CallOption) (*ChatResponse, error)
ChatStream(ctx context.Context, in *ChatStreamRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[ChatStreamEvent], error)
// Structured output — one-shot, stateless. The runtime hands a
// user prompt + JSON schema to the underlying LanguageModel via
// fantasy.GenerateObject; the schema drives whichever native
// JSON / tool / text mode the provider supports. No session
// memory, no tool loop.
PromptObject(ctx context.Context, in *PromptObjectRequest, opts ...grpc.CallOption) (*PromptObjectResponse, error)
// Sessions
ListSessions(ctx context.Context, in *ListSessionsRequest, opts ...grpc.CallOption) (*ListSessionsResponse, error)
DeleteSession(ctx context.Context, in *DeleteSessionRequest, opts ...grpc.CallOption) (*DeleteSessionResponse, error)
ListSessionMessages(ctx context.Context, in *ListSessionMessagesRequest, opts ...grpc.CallOption) (*ListSessionMessagesResponse, error)
// Probes
Health(ctx context.Context, in *HealthRequest, opts ...grpc.CallOption) (*HealthResponse, error)
Ready(ctx context.Context, in *ReadyRequest, opts ...grpc.CallOption) (*ReadyResponse, error)
}
AgentRuntimeClient is the client API for AgentRuntime service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewAgentRuntimeClient ¶
func NewAgentRuntimeClient(cc grpc.ClientConnInterface) AgentRuntimeClient
type AgentRuntimeServer ¶
type AgentRuntimeServer interface {
// Chat
Chat(context.Context, *ChatRequest) (*ChatResponse, error)
ChatStream(*ChatStreamRequest, grpc.ServerStreamingServer[ChatStreamEvent]) error
// Structured output — one-shot, stateless. The runtime hands a
// user prompt + JSON schema to the underlying LanguageModel via
// fantasy.GenerateObject; the schema drives whichever native
// JSON / tool / text mode the provider supports. No session
// memory, no tool loop.
PromptObject(context.Context, *PromptObjectRequest) (*PromptObjectResponse, error)
// Sessions
ListSessions(context.Context, *ListSessionsRequest) (*ListSessionsResponse, error)
DeleteSession(context.Context, *DeleteSessionRequest) (*DeleteSessionResponse, error)
ListSessionMessages(context.Context, *ListSessionMessagesRequest) (*ListSessionMessagesResponse, error)
// Probes
Health(context.Context, *HealthRequest) (*HealthResponse, error)
Ready(context.Context, *ReadyRequest) (*ReadyResponse, error)
// contains filtered or unexported methods
}
AgentRuntimeServer is the server API for AgentRuntime service. All implementations must embed UnimplementedAgentRuntimeServer for forward compatibility.
type AgentRuntime_ChatStreamClient ¶
type AgentRuntime_ChatStreamClient = grpc.ServerStreamingClient[ChatStreamEvent]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type AgentRuntime_ChatStreamServer ¶
type AgentRuntime_ChatStreamServer = grpc.ServerStreamingServer[ChatStreamEvent]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type ChatRequest ¶
type ChatRequest struct {
SessionId string `protobuf:"bytes,1,opt,name=session_id,json=sessionId,proto3" json:"session_id,omitempty"`
Prompt string `protobuf:"bytes,2,opt,name=prompt,proto3" json:"prompt,omitempty"`
// contains filtered or unexported fields
}
func (*ChatRequest) Descriptor
deprecated
func (*ChatRequest) Descriptor() ([]byte, []int)
Deprecated: Use ChatRequest.ProtoReflect.Descriptor instead.
func (*ChatRequest) GetPrompt ¶
func (x *ChatRequest) GetPrompt() string
func (*ChatRequest) GetSessionId ¶
func (x *ChatRequest) GetSessionId() string
func (*ChatRequest) ProtoMessage ¶
func (*ChatRequest) ProtoMessage()
func (*ChatRequest) ProtoReflect ¶
func (x *ChatRequest) ProtoReflect() protoreflect.Message
func (*ChatRequest) Reset ¶
func (x *ChatRequest) Reset()
func (*ChatRequest) String ¶
func (x *ChatRequest) String() string
type ChatResponse ¶
type ChatResponse struct {
Response string `protobuf:"bytes,1,opt,name=response,proto3" json:"response,omitempty"`
// contains filtered or unexported fields
}
func (*ChatResponse) Descriptor
deprecated
func (*ChatResponse) Descriptor() ([]byte, []int)
Deprecated: Use ChatResponse.ProtoReflect.Descriptor instead.
func (*ChatResponse) GetResponse ¶
func (x *ChatResponse) GetResponse() string
func (*ChatResponse) ProtoMessage ¶
func (*ChatResponse) ProtoMessage()
func (*ChatResponse) ProtoReflect ¶
func (x *ChatResponse) ProtoReflect() protoreflect.Message
func (*ChatResponse) Reset ¶
func (x *ChatResponse) Reset()
func (*ChatResponse) String ¶
func (x *ChatResponse) String() string
type ChatStreamEvent ¶
type ChatStreamEvent struct {
Type string `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
Step int32 `protobuf:"varint,2,opt,name=step,proto3" json:"step,omitempty"`
Tool string `protobuf:"bytes,3,opt,name=tool,proto3" json:"tool,omitempty"`
Content string `protobuf:"bytes,4,opt,name=content,proto3" json:"content,omitempty"`
// contains filtered or unexported fields
}
func (*ChatStreamEvent) Descriptor
deprecated
func (*ChatStreamEvent) Descriptor() ([]byte, []int)
Deprecated: Use ChatStreamEvent.ProtoReflect.Descriptor instead.
func (*ChatStreamEvent) GetContent ¶
func (x *ChatStreamEvent) GetContent() string
func (*ChatStreamEvent) GetStep ¶
func (x *ChatStreamEvent) GetStep() int32
func (*ChatStreamEvent) GetTool ¶
func (x *ChatStreamEvent) GetTool() string
func (*ChatStreamEvent) GetType ¶
func (x *ChatStreamEvent) GetType() string
func (*ChatStreamEvent) ProtoMessage ¶
func (*ChatStreamEvent) ProtoMessage()
func (*ChatStreamEvent) ProtoReflect ¶
func (x *ChatStreamEvent) ProtoReflect() protoreflect.Message
func (*ChatStreamEvent) Reset ¶
func (x *ChatStreamEvent) Reset()
func (*ChatStreamEvent) String ¶
func (x *ChatStreamEvent) String() string
type ChatStreamRequest ¶
type ChatStreamRequest struct {
SessionId string `protobuf:"bytes,1,opt,name=session_id,json=sessionId,proto3" json:"session_id,omitempty"`
Prompt string `protobuf:"bytes,2,opt,name=prompt,proto3" json:"prompt,omitempty"`
// When true, the runtime appends the produced parts as a new
// branch onto the most recent assistant turn for session_id
// instead of inserting a fresh row. Falls back to insert when
// no prior assistant turn exists.
Regenerate bool `protobuf:"varint,3,opt,name=regenerate,proto3" json:"regenerate,omitempty"`
// contains filtered or unexported fields
}
func (*ChatStreamRequest) Descriptor
deprecated
func (*ChatStreamRequest) Descriptor() ([]byte, []int)
Deprecated: Use ChatStreamRequest.ProtoReflect.Descriptor instead.
func (*ChatStreamRequest) GetPrompt ¶
func (x *ChatStreamRequest) GetPrompt() string
func (*ChatStreamRequest) GetRegenerate ¶
func (x *ChatStreamRequest) GetRegenerate() bool
func (*ChatStreamRequest) GetSessionId ¶
func (x *ChatStreamRequest) GetSessionId() string
func (*ChatStreamRequest) ProtoMessage ¶
func (*ChatStreamRequest) ProtoMessage()
func (*ChatStreamRequest) ProtoReflect ¶
func (x *ChatStreamRequest) ProtoReflect() protoreflect.Message
func (*ChatStreamRequest) Reset ¶
func (x *ChatStreamRequest) Reset()
func (*ChatStreamRequest) String ¶
func (x *ChatStreamRequest) String() string
type DeleteSessionRequest ¶
type DeleteSessionRequest struct {
SessionId string `protobuf:"bytes,1,opt,name=session_id,json=sessionId,proto3" json:"session_id,omitempty"`
// contains filtered or unexported fields
}
func (*DeleteSessionRequest) Descriptor
deprecated
func (*DeleteSessionRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteSessionRequest.ProtoReflect.Descriptor instead.
func (*DeleteSessionRequest) GetSessionId ¶
func (x *DeleteSessionRequest) GetSessionId() string
func (*DeleteSessionRequest) ProtoMessage ¶
func (*DeleteSessionRequest) ProtoMessage()
func (*DeleteSessionRequest) ProtoReflect ¶
func (x *DeleteSessionRequest) ProtoReflect() protoreflect.Message
func (*DeleteSessionRequest) Reset ¶
func (x *DeleteSessionRequest) Reset()
func (*DeleteSessionRequest) String ¶
func (x *DeleteSessionRequest) String() string
type DeleteSessionResponse ¶
type DeleteSessionResponse struct {
// contains filtered or unexported fields
}
func (*DeleteSessionResponse) Descriptor
deprecated
func (*DeleteSessionResponse) Descriptor() ([]byte, []int)
Deprecated: Use DeleteSessionResponse.ProtoReflect.Descriptor instead.
func (*DeleteSessionResponse) ProtoMessage ¶
func (*DeleteSessionResponse) ProtoMessage()
func (*DeleteSessionResponse) ProtoReflect ¶
func (x *DeleteSessionResponse) ProtoReflect() protoreflect.Message
func (*DeleteSessionResponse) Reset ¶
func (x *DeleteSessionResponse) Reset()
func (*DeleteSessionResponse) String ¶
func (x *DeleteSessionResponse) String() string
type HealthRequest ¶
type HealthRequest struct {
// contains filtered or unexported fields
}
func (*HealthRequest) Descriptor
deprecated
func (*HealthRequest) Descriptor() ([]byte, []int)
Deprecated: Use HealthRequest.ProtoReflect.Descriptor instead.
func (*HealthRequest) ProtoMessage ¶
func (*HealthRequest) ProtoMessage()
func (*HealthRequest) ProtoReflect ¶
func (x *HealthRequest) ProtoReflect() protoreflect.Message
func (*HealthRequest) Reset ¶
func (x *HealthRequest) Reset()
func (*HealthRequest) String ¶
func (x *HealthRequest) String() string
type HealthResponse ¶
type HealthResponse struct {
Status string `protobuf:"bytes,1,opt,name=status,proto3" json:"status,omitempty"`
AgentName string `protobuf:"bytes,2,opt,name=agent_name,json=agentName,proto3" json:"agent_name,omitempty"`
Model string `protobuf:"bytes,3,opt,name=model,proto3" json:"model,omitempty"`
// contains filtered or unexported fields
}
func (*HealthResponse) Descriptor
deprecated
func (*HealthResponse) Descriptor() ([]byte, []int)
Deprecated: Use HealthResponse.ProtoReflect.Descriptor instead.
func (*HealthResponse) GetAgentName ¶
func (x *HealthResponse) GetAgentName() string
func (*HealthResponse) GetModel ¶
func (x *HealthResponse) GetModel() string
func (*HealthResponse) GetStatus ¶
func (x *HealthResponse) GetStatus() string
func (*HealthResponse) ProtoMessage ¶
func (*HealthResponse) ProtoMessage()
func (*HealthResponse) ProtoReflect ¶
func (x *HealthResponse) ProtoReflect() protoreflect.Message
func (*HealthResponse) Reset ¶
func (x *HealthResponse) Reset()
func (*HealthResponse) String ¶
func (x *HealthResponse) String() string
type ListSessionMessagesRequest ¶
type ListSessionMessagesRequest struct {
SessionId string `protobuf:"bytes,1,opt,name=session_id,json=sessionId,proto3" json:"session_id,omitempty"`
Limit int32 `protobuf:"varint,2,opt,name=limit,proto3" json:"limit,omitempty"` // 0 = server default
// contains filtered or unexported fields
}
func (*ListSessionMessagesRequest) Descriptor
deprecated
func (*ListSessionMessagesRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListSessionMessagesRequest.ProtoReflect.Descriptor instead.
func (*ListSessionMessagesRequest) GetLimit ¶
func (x *ListSessionMessagesRequest) GetLimit() int32
func (*ListSessionMessagesRequest) GetSessionId ¶
func (x *ListSessionMessagesRequest) GetSessionId() string
func (*ListSessionMessagesRequest) ProtoMessage ¶
func (*ListSessionMessagesRequest) ProtoMessage()
func (*ListSessionMessagesRequest) ProtoReflect ¶
func (x *ListSessionMessagesRequest) ProtoReflect() protoreflect.Message
func (*ListSessionMessagesRequest) Reset ¶
func (x *ListSessionMessagesRequest) Reset()
func (*ListSessionMessagesRequest) String ¶
func (x *ListSessionMessagesRequest) String() string
type ListSessionMessagesResponse ¶
type ListSessionMessagesResponse struct {
Messages []*SessionMessage `protobuf:"bytes,1,rep,name=messages,proto3" json:"messages,omitempty"`
// contains filtered or unexported fields
}
func (*ListSessionMessagesResponse) Descriptor
deprecated
func (*ListSessionMessagesResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListSessionMessagesResponse.ProtoReflect.Descriptor instead.
func (*ListSessionMessagesResponse) GetMessages ¶
func (x *ListSessionMessagesResponse) GetMessages() []*SessionMessage
func (*ListSessionMessagesResponse) ProtoMessage ¶
func (*ListSessionMessagesResponse) ProtoMessage()
func (*ListSessionMessagesResponse) ProtoReflect ¶
func (x *ListSessionMessagesResponse) ProtoReflect() protoreflect.Message
func (*ListSessionMessagesResponse) Reset ¶
func (x *ListSessionMessagesResponse) Reset()
func (*ListSessionMessagesResponse) String ¶
func (x *ListSessionMessagesResponse) String() string
type ListSessionsRequest ¶
type ListSessionsRequest struct {
// contains filtered or unexported fields
}
func (*ListSessionsRequest) Descriptor
deprecated
func (*ListSessionsRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListSessionsRequest.ProtoReflect.Descriptor instead.
func (*ListSessionsRequest) ProtoMessage ¶
func (*ListSessionsRequest) ProtoMessage()
func (*ListSessionsRequest) ProtoReflect ¶
func (x *ListSessionsRequest) ProtoReflect() protoreflect.Message
func (*ListSessionsRequest) Reset ¶
func (x *ListSessionsRequest) Reset()
func (*ListSessionsRequest) String ¶
func (x *ListSessionsRequest) String() string
type ListSessionsResponse ¶
type ListSessionsResponse struct {
Sessions []*SessionInfo `protobuf:"bytes,1,rep,name=sessions,proto3" json:"sessions,omitempty"`
// contains filtered or unexported fields
}
func (*ListSessionsResponse) Descriptor
deprecated
func (*ListSessionsResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListSessionsResponse.ProtoReflect.Descriptor instead.
func (*ListSessionsResponse) GetSessions ¶
func (x *ListSessionsResponse) GetSessions() []*SessionInfo
func (*ListSessionsResponse) ProtoMessage ¶
func (*ListSessionsResponse) ProtoMessage()
func (*ListSessionsResponse) ProtoReflect ¶
func (x *ListSessionsResponse) ProtoReflect() protoreflect.Message
func (*ListSessionsResponse) Reset ¶
func (x *ListSessionsResponse) Reset()
func (*ListSessionsResponse) String ¶
func (x *ListSessionsResponse) String() string
type PromptObjectRequest ¶
type PromptObjectRequest struct {
// Plain-text user prompt (single turn; stateless).
Prompt string `protobuf:"bytes,1,opt,name=prompt,proto3" json:"prompt,omitempty"`
// Raw JSON Schema bytes. Unmarshalled into fantasy/schema.Schema
// server-side; the common subset (type, properties, required,
// items, enum, format, min/max) is supported.
SchemaJson []byte `protobuf:"bytes,2,opt,name=schema_json,json=schemaJson,proto3" json:"schema_json,omitempty"`
// Optional — surfaces in tool-mode providers as the synthetic
// tool's name / description. Ignored otherwise.
SchemaName string `protobuf:"bytes,3,opt,name=schema_name,json=schemaName,proto3" json:"schema_name,omitempty"`
SchemaDesc string `protobuf:"bytes,4,opt,name=schema_desc,json=schemaDesc,proto3" json:"schema_desc,omitempty"`
// contains filtered or unexported fields
}
func (*PromptObjectRequest) Descriptor
deprecated
func (*PromptObjectRequest) Descriptor() ([]byte, []int)
Deprecated: Use PromptObjectRequest.ProtoReflect.Descriptor instead.
func (*PromptObjectRequest) GetPrompt ¶
func (x *PromptObjectRequest) GetPrompt() string
func (*PromptObjectRequest) GetSchemaDesc ¶
func (x *PromptObjectRequest) GetSchemaDesc() string
func (*PromptObjectRequest) GetSchemaJson ¶
func (x *PromptObjectRequest) GetSchemaJson() []byte
func (*PromptObjectRequest) GetSchemaName ¶
func (x *PromptObjectRequest) GetSchemaName() string
func (*PromptObjectRequest) ProtoMessage ¶
func (*PromptObjectRequest) ProtoMessage()
func (*PromptObjectRequest) ProtoReflect ¶
func (x *PromptObjectRequest) ProtoReflect() protoreflect.Message
func (*PromptObjectRequest) Reset ¶
func (x *PromptObjectRequest) Reset()
func (*PromptObjectRequest) String ¶
func (x *PromptObjectRequest) String() string
type PromptObjectResponse ¶
type PromptObjectResponse struct {
// Marshalled structured object (valid JSON bytes).
ObjectJson []byte `protobuf:"bytes,1,opt,name=object_json,json=objectJson,proto3" json:"object_json,omitempty"`
// The raw assistant text, mostly useful when the model returned
// repaired or otherwise interesting content alongside the parse.
RawText string `protobuf:"bytes,2,opt,name=raw_text,json=rawText,proto3" json:"raw_text,omitempty"`
// contains filtered or unexported fields
}
func (*PromptObjectResponse) Descriptor
deprecated
func (*PromptObjectResponse) Descriptor() ([]byte, []int)
Deprecated: Use PromptObjectResponse.ProtoReflect.Descriptor instead.
func (*PromptObjectResponse) GetObjectJson ¶
func (x *PromptObjectResponse) GetObjectJson() []byte
func (*PromptObjectResponse) GetRawText ¶
func (x *PromptObjectResponse) GetRawText() string
func (*PromptObjectResponse) ProtoMessage ¶
func (*PromptObjectResponse) ProtoMessage()
func (*PromptObjectResponse) ProtoReflect ¶
func (x *PromptObjectResponse) ProtoReflect() protoreflect.Message
func (*PromptObjectResponse) Reset ¶
func (x *PromptObjectResponse) Reset()
func (*PromptObjectResponse) String ¶
func (x *PromptObjectResponse) String() string
type ReadyRequest ¶
type ReadyRequest struct {
// contains filtered or unexported fields
}
func (*ReadyRequest) Descriptor
deprecated
func (*ReadyRequest) Descriptor() ([]byte, []int)
Deprecated: Use ReadyRequest.ProtoReflect.Descriptor instead.
func (*ReadyRequest) ProtoMessage ¶
func (*ReadyRequest) ProtoMessage()
func (*ReadyRequest) ProtoReflect ¶
func (x *ReadyRequest) ProtoReflect() protoreflect.Message
func (*ReadyRequest) Reset ¶
func (x *ReadyRequest) Reset()
func (*ReadyRequest) String ¶
func (x *ReadyRequest) String() string
type ReadyResponse ¶
type ReadyResponse struct {
Ready bool `protobuf:"varint,1,opt,name=ready,proto3" json:"ready,omitempty"`
// contains filtered or unexported fields
}
func (*ReadyResponse) Descriptor
deprecated
func (*ReadyResponse) Descriptor() ([]byte, []int)
Deprecated: Use ReadyResponse.ProtoReflect.Descriptor instead.
func (*ReadyResponse) GetReady ¶
func (x *ReadyResponse) GetReady() bool
func (*ReadyResponse) ProtoMessage ¶
func (*ReadyResponse) ProtoMessage()
func (*ReadyResponse) ProtoReflect ¶
func (x *ReadyResponse) ProtoReflect() protoreflect.Message
func (*ReadyResponse) Reset ¶
func (x *ReadyResponse) Reset()
func (*ReadyResponse) String ¶
func (x *ReadyResponse) String() string
type SessionInfo ¶
type SessionInfo struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
MessageCount int32 `protobuf:"varint,2,opt,name=message_count,json=messageCount,proto3" json:"message_count,omitempty"`
LastActive int64 `protobuf:"varint,3,opt,name=last_active,json=lastActive,proto3" json:"last_active,omitempty"`
// contains filtered or unexported fields
}
func (*SessionInfo) Descriptor
deprecated
func (*SessionInfo) Descriptor() ([]byte, []int)
Deprecated: Use SessionInfo.ProtoReflect.Descriptor instead.
func (*SessionInfo) GetId ¶
func (x *SessionInfo) GetId() string
func (*SessionInfo) GetLastActive ¶
func (x *SessionInfo) GetLastActive() int64
func (*SessionInfo) GetMessageCount ¶
func (x *SessionInfo) GetMessageCount() int32
func (*SessionInfo) ProtoMessage ¶
func (*SessionInfo) ProtoMessage()
func (*SessionInfo) ProtoReflect ¶
func (x *SessionInfo) ProtoReflect() protoreflect.Message
func (*SessionInfo) Reset ¶
func (x *SessionInfo) Reset()
func (*SessionInfo) String ¶
func (x *SessionInfo) String() string
type SessionMessage ¶
type SessionMessage struct {
Role string `protobuf:"bytes,1,opt,name=role,proto3" json:"role,omitempty"` // "user" | "assistant"
Content string `protobuf:"bytes,2,opt,name=content,proto3" json:"content,omitempty"` // user: prompt text. assistant: JSON parts array.
CreatedAt int64 `protobuf:"varint,3,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"` // unix seconds
BranchesJson string `protobuf:"bytes,4,opt,name=branches_json,json=branchesJson,proto3" json:"branches_json,omitempty"` // assistant only: JSON array of alternative parts arrays
ActiveBranch int32 `protobuf:"varint,5,opt,name=active_branch,json=activeBranch,proto3" json:"active_branch,omitempty"` // assistant only: index of currently-active branch
// contains filtered or unexported fields
}
func (*SessionMessage) Descriptor
deprecated
func (*SessionMessage) Descriptor() ([]byte, []int)
Deprecated: Use SessionMessage.ProtoReflect.Descriptor instead.
func (*SessionMessage) GetActiveBranch ¶
func (x *SessionMessage) GetActiveBranch() int32
func (*SessionMessage) GetBranchesJson ¶
func (x *SessionMessage) GetBranchesJson() string
func (*SessionMessage) GetContent ¶
func (x *SessionMessage) GetContent() string
func (*SessionMessage) GetCreatedAt ¶
func (x *SessionMessage) GetCreatedAt() int64
func (*SessionMessage) GetRole ¶
func (x *SessionMessage) GetRole() string
func (*SessionMessage) ProtoMessage ¶
func (*SessionMessage) ProtoMessage()
func (*SessionMessage) ProtoReflect ¶
func (x *SessionMessage) ProtoReflect() protoreflect.Message
func (*SessionMessage) Reset ¶
func (x *SessionMessage) Reset()
func (*SessionMessage) String ¶
func (x *SessionMessage) String() string
type UnimplementedAgentRuntimeServer ¶
type UnimplementedAgentRuntimeServer struct{}
UnimplementedAgentRuntimeServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedAgentRuntimeServer) Chat ¶
func (UnimplementedAgentRuntimeServer) Chat(context.Context, *ChatRequest) (*ChatResponse, error)
func (UnimplementedAgentRuntimeServer) ChatStream ¶
func (UnimplementedAgentRuntimeServer) ChatStream(*ChatStreamRequest, grpc.ServerStreamingServer[ChatStreamEvent]) error
func (UnimplementedAgentRuntimeServer) DeleteSession ¶
func (UnimplementedAgentRuntimeServer) DeleteSession(context.Context, *DeleteSessionRequest) (*DeleteSessionResponse, error)
func (UnimplementedAgentRuntimeServer) Health ¶
func (UnimplementedAgentRuntimeServer) Health(context.Context, *HealthRequest) (*HealthResponse, error)
func (UnimplementedAgentRuntimeServer) ListSessionMessages ¶
func (UnimplementedAgentRuntimeServer) ListSessionMessages(context.Context, *ListSessionMessagesRequest) (*ListSessionMessagesResponse, error)
func (UnimplementedAgentRuntimeServer) ListSessions ¶
func (UnimplementedAgentRuntimeServer) ListSessions(context.Context, *ListSessionsRequest) (*ListSessionsResponse, error)
func (UnimplementedAgentRuntimeServer) PromptObject ¶
func (UnimplementedAgentRuntimeServer) PromptObject(context.Context, *PromptObjectRequest) (*PromptObjectResponse, error)
func (UnimplementedAgentRuntimeServer) Ready ¶
func (UnimplementedAgentRuntimeServer) Ready(context.Context, *ReadyRequest) (*ReadyResponse, error)
type UnsafeAgentRuntimeServer ¶
type UnsafeAgentRuntimeServer interface {
// contains filtered or unexported methods
}
UnsafeAgentRuntimeServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AgentRuntimeServer will result in compilation errors.